@@ -9,7 +9,7 @@
 #   Andrew Ford    <a.ford@ford-mason.co.uk>
 #
 # COPYRIGHT
-#   Copyright (C) 2007 Andrew Ford.  All Rights Reserved.
+#   Copyright (C) 2007-2012 Andrew Ford.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
@@ -18,7 +18,7 @@
 #   * Module extracted from Template::Latex module originally by Andy Wardley,
 #     September 2007
 #
-#   $Id: Paths.pm 16 2007-09-21 23:03:09Z andrew $
+#   $Id: Paths.pm 84 2012-08-30 20:19:25Z andrew $
 #========================================================================
  
 package LaTeX::Driver::Paths;
@@ -31,11 +31,14 @@ use warnings;
 our %program_path;
 
 $program_path{latex}     = '/usr/bin/latex';
+$program_path{xelatex}   = '/usr/bin/xelatex';
 $program_path{pdflatex}  = '/usr/bin/pdflatex';
-$program_path{dvips}     = '/usr/bin/dvips';
-$program_path{ps2pdf}    = '/usr/bin/ps2pdf';
 $program_path{bibtex}    = '/usr/bin/bibtex';
 $program_path{makeindex} = '/usr/bin/makeindex';
+$program_path{dvips}     = '/usr/bin/dvips';
+$program_path{dvipdfm}   = '/usr/bin/dvipdfm';
+$program_path{pdf2ps}    = '/usr/bin/pdf2ps';
+$program_path{ps2pdf}    = '/usr/bin/pdf2ps';
 
 1;
 
